==> flutter_integration-0.0.1.tar.gz: ios/Classes/FlutterIntegrationHostViewController.m <==
//
//  FlutterIntegrationHostViewController.m
//  IGame
//
//  Created by junshao on 2019/12/11.
//  Copyright © 2019 Tencent. All rights reserved.
//

#import "FlutterIntegrationHostViewController.h"
#import <Flutter/Flutter.h>
#import "FlutterIntegrationViewController.h"
#import "FlutterIntegrationManager.h"

@interface FlutterIntegrationHostViewController()

@property (nonatomic, strong) FlutterEngine *flutterEngine;
@property (nonatomic, strong) FlutterIntegrationViewController *flutterViewController;
@property (nonatomic, strong) FlutterMethodChannel *methodChannel;

@end

@implementation FlutterIntegrationHostViewController

-(instancetype)initWithRouteName:(NSString *)routeName params:(NSObject *)params {
    self = [super init];
    if(self){
        _routeName = routeName;
        _params = params;
        _flutterVC = FlutterIntegrationViewController.class;
    }
    return self;
}

- (NSString *)pageId {
    if (_pageId == nil) {
        double timestamp = [[NSDate date] timeIntervalSince1970];
        _pageId = [NSString stringWithFormat:@"%@_%lf", _routeName, timestamp];
    }
    return _pageId;
}

- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];
    self.flutterEngine = [FlutterIntegrationManager sharedInstance].flutterEngineContainer.flutterEngine;
    self.methodChannel = [FlutterIntegrationManager sharedInstance].flutterEngineContainer.flutterMethodChannel;
    
    [self.view setNeedsLayout];
}

-(void)viewDidAppear:(BOOL)animated{
    if (!self.flutterViewController) {
        [self createFlutterViewController];
    }
    if(self.flutterEngine.viewController != self.flutterViewController){
        [((FlutterIntegrationViewController *)self.flutterEngine.viewController) surfaceUpdated:NO];
        self.flutterEngine.viewController = self.flutterViewController;
    }
    //必须要初始化channel后才能调用openPage
    [self openPage];
    [self.flutterViewController surfaceUpdated:YES];
    [super viewDidAppear:animated];
}

- (void)viewDidDisappear:(BOOL)animated {
    self.flutterEngine.viewController = [FlutterIntegrationManager sharedInstance].dummyVC;
    [super viewDidDisappear:animated];
}

-(void)dealloc{
    [self removePage];
}

- (UIStatusBarStyle)preferredStatusBarStyle{
    return UIStatusBarStyleLightContent;
}

- (void)createFlutterViewController {
    _flutterViewController = [self newFlutterViewController];
    __weak __typeof(self) weakSelf = self;
    [_flutterViewController setFlutterViewDidRenderCallback:^{
        // 首页是flutter页面时特殊处理，渲染完成后再调一次openPage
        // 因为之前openPage在flutter的runApp前，界面还没初始化，无法生效
        __strong __typeof(weakSelf) strongSelf = weakSelf;
        NSLog(@"setFlutterViewDidRenderCallback");
        if (strongSelf.firstPageInApp) {
            [strongSelf openPage];
        }
    }];
    self.flutterViewController.view.frame = CGRectMake(0, 0, self.view.frame.size.width, self.view.frame.size.height);
    [self addChildViewController:self.flutterViewController];
    [self.view addSubview:self.flutterViewController.view];
    [self.flutterViewController didMoveToParentViewController:self];
}

- (FlutterIntegrationViewController *)newFlutterViewController {
    if (self.flutterVC && [self.flutterVC isSubclassOfClass:FlutterIntegrationViewController.class]) {
        FlutterIntegrationViewController *flutterViewController = [[self.flutterVC alloc] initWithEngine:self.flutterEngine nibName:nil bundle:nil];
        return flutterViewController;
    } else {
        NSLog(@"flutterVC参数类型错误，不是FlutterIntegrationViewController的子类");
        FlutterIntegrationViewController *flutterViewController = [[FlutterIntegrationViewController alloc] initWithEngine:self.flutterEngine nibName:nil bundle:nil];
        return flutterViewController;
    }
}

-(void)openPage{
    NSMutableDictionary *arguments = [@{@"routeName": self.routeName, @"pageId": self.pageId} mutableCopy];
    if(self.params){
        arguments[@"params"] = self.params;
    }
    [self.methodChannel invokeMethod:@"openPage" arguments:arguments];
}

-(void)removePage{
    NSDictionary *arguments = @{@"routeName": self.routeName, @"pageId": self.pageId};
    [self.methodChannel invokeMethod:@"removePage" arguments:arguments];
}

@end

==> flutter_integration-0.0.7.tar.gz: ios/Classes/FlutterIntegrationHostViewController.m <==
//
//  FlutterIntegrationHostViewController.m
//  IGame
//
//  Created by junshao on 2019/12/11.
//  Copyright © 2019 Tencent. All rights reserved.
//

#import "FlutterIntegrationHostViewController.h"
#import <Flutter/Flutter.h>
#import "FlutterIntegrationViewController.h"
#import "FlutterIntegrationManager.h"

@interface FlutterIntegrationHostViewController()

@property (nonatomic, strong) FlutterEngine *flutterEngine;
@property (nonatomic, strong) FlutterIntegrationViewController *flutterViewController;
@property (nonatomic, strong) FlutterMethodChannel *methodChannel;

@property (nonatomic, assign) BOOL isFirstViewWillAppear;

@end

@implementation FlutterIntegrationHostViewController

-(instancetype)init{
    self = [super init];
    if(self){
        _isFirstViewWillAppear = YES;
    }
    return self;
}

-(instancetype)initWithRouteName:(NSString *)routeName params:(NSObject *)params {
    self = [super init];
    if(self){
        _routeName = routeName;
        _params = params;
        _isFirstViewWillAppear = YES;
    }
    return self;
}

- (NSString *)pageId {
    if (_pageId == nil) {
        double timestamp = [[NSDate date] timeIntervalSince1970];
        _pageId = [NSString stringWithFormat:@"%@_%lf", _routeName, timestamp];
    }
    return _pageId;
}

- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];
    self.flutterEngine = [FlutterIntegrationManager sharedInstance].flutterEngineContainer.flutterEngine;
    self.methodChannel = [FlutterIntegrationManager sharedInstance].flutterEngineContainer.flutterMethodChannel;
    
    if(self.isFirstViewWillAppear){
        [self attachEngine];
        self.isFirstViewWillAppear = NO;
    }
    
    [self.view setNeedsLayout];
}

-(void)viewDidAppear:(BOOL)animated{
    [self attachEngine];
    [super viewDidAppear:animated];
}

- (void)viewDidDisappear:(BOOL)animated {
    [self dettachEngine];
    [super viewDidDisappear:animated];
}

-(void)dealloc{
    [self removePage];
}

- (UIStatusBarStyle)preferredStatusBarStyle{
    return UIStatusBarStyleLightContent;
}

-(void)attachEngine{
    if (!self.flutterViewController) {
        [self createFlutterViewController];
    }

    if(self.flutterEngine.viewController != self.flutterViewController){
        [((FlutterIntegrationViewController *)self.flutterEngine.viewController) surfaceUpdated:NO];
        self.flutterEngine.viewController = self.flutterViewController;
    }
    //必须要初始化channel后才能调用openPage
    [self openPage];
    [self.flutterViewController surfaceUpdated:YES];
}

-(void)dettachEngine{
    if(self.flutterEngine.viewController == self.flutterViewController){
        self.flutterEngine.viewController = [FlutterIntegrationManager sharedInstance].holderVC;
    }
}

- (void)createFlutterViewController {
    _flutterViewController = [self newFlutterViewController];
    __weak __typeof(self) weakSelf = self;
    [_flutterViewController setFlutterViewDidRenderCallback:^{
        // 首页是flutter页面时特殊处理，渲染完成后再调一次openPage
        // 因为之前openPage在flutter的runApp前，界面还没初始化，无法生效
        __strong __typeof(weakSelf) strongSelf = weakSelf;
        if (strongSelf.firstPageInApp) {
            [strongSelf openPage];
        }
    }];
    self.flutterViewController.view.frame = CGRectMake(0, 0, self.view.frame.size.width, self.view.frame.size.height);
    [self addChildViewController:self.flutterViewController];
    [self.view addSubview:self.flutterViewController.view];
    [self.flutterViewController didMoveToParentViewController:self];
}

- (FlutterIntegrationViewController *)newFlutterViewController {
    FlutterIntegrationViewController *flutterViewController = [[FlutterIntegrationViewController alloc] initWithEngine:self.flutterEngine nibName:nil bundle:nil];
    return flutterViewController;
}

-(void)openPage{
    NSMutableDictionary *arguments = [@{@"routeName": self.routeName, @"pageId": self.pageId} mutableCopy];
    if(self.params){
        arguments[@"params"] = self.params;
    }
    [self.methodChannel invokeMethod:@"openPage" arguments:arguments];
}

-(void)removePage{
    NSDictionary *arguments = @{@"routeName": self.routeName, @"pageId": self.pageId};
    [self.methodChannel invokeMethod:@"removePage" arguments:arguments];
}

@end
